==> lori_sdk-0.3.0.tar.gz: lib/data/api/sales/sales_catalog_api.dart <==
import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:lori_sdk/data/lori_api.dart';
import 'package:lori_sdk/data/models/addressCep.dart';
import 'package:lori_sdk/data/models/product/product.dart';
import 'package:lori_sdk/data/models/product/productOrder.dart';
import 'package:lori_sdk/data/models/response/productPaginationResult.dart';
import 'package:lori_sdk/data/models/v2/category.dart';


class SalesCatalogApi {
  static const API_CATEGORIES = '/sales/catalog/categories';
  static const API_CATEGORIES_CHILDREN = '/sales/catalog/categories/%/children';

  static const API_PRODUCT_BY_ID = '/sales/catalog/products/%';
  static const API_PRODUCTS_BY_CATEGORY = '/sales/catalog/categories/%/products';
  static const API_PRODUCTS_BY_SEARCH_TERM = '/sales/catalog/products/search/%';
  static const API_PRODUCTS_BY_TAG = '/sales/catalog/tags/%/products';

  Dio _requester;

  SalesCatalogApi({@required Dio requester}) : this._requester = requester;

  /// region Category API endpoints

  Future<ApiCallback<List<Category>>> getCategories() async {
    try {
      var response = await _requester.get(API_CATEGORIES,
          options: Options(responseType: ResponseType.json));
      var responseData = response.data as List;
      var categories = List<Category>();
      for (var row in responseData) {
        categories.add(Category.fromJson(row));
      }
      categories.sort((c1, c2) => c1.name.compareTo(c2.name));
      return ApiCallback<List<Category>>(
          isSuccessful: true, resultData: categories);
    } on DioError catch (e) {
      return ApiCallback.defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<List<Category>>> getChildrenCategories({String parentCategoryId}) async {
    try {
      var response = await _requester.get(API_CATEGORIES_CHILDREN.replaceAll('%', parentCategoryId),
        options: Options(responseType: ResponseType.json));
      var responseData = response.data as List;
      var categories = List<Category>();
      for (var row in responseData) {
        categories.add(Category.fromJson(row));
      }
      return ApiCallback<List<Category>>(
          isSuccessful: true, resultData: categories);
    } on DioError catch (e) {
      return ApiCallback.defaultErrorCallback(e);
    }
  }

  /// endregion

  /// region Product API endpoints

  Future<ApiCallback<Product>> getProduct(String productId) async {
    try {
      var response = await _requester.get(API_PRODUCT_BY_ID.replaceAll('%', productId));
      return ApiCallback<Product>(
          isSuccessful: true, resultData: Product.fromJson(response.data));
    } on DioError catch (e) {
      return ApiCallback.defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<ProductPaginationResult>> getProductsByCategory({String categoryId, int page = 1, int perPage = 20, String continuationToken, ProductOrder sort}) async {
    Map<String, dynamic> queryParameters = {
      'page': page,
      'perPage': perPage
    };

    queryParameters.addAll(_queryParametersForPagedProductRequest(continuationToken: continuationToken, sort: sort));

    try {
      Stopwatch stopwatch = new Stopwatch()..start();
      var response = await _requester.get(API_PRODUCTS_BY_CATEGORY.replaceAll("%", categoryId),
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));
      var paginationResult = ProductPaginationResult.fromJson(response.data);
      print("Page ${paginationResult.page}/${paginationResult.maxPage} loaded in ${stopwatch.elapsedMilliseconds}ms");
      return ApiCallback(
          isSuccessful: true,
          resultData: paginationResult);
    } on DioError catch (e) {
      return ApiCallback.defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<ProductPaginationResult>> getProductsBySearch({String term, int page = 1, int perPage = 20, String continuationToken, ProductOrder sort}) async {
    Map<String, dynamic> queryParameters = {
      'page': page,
      'perPage': perPage
    };

    queryParameters.addAll(_queryParametersForPagedProductRequest(continuationToken: continuationToken, sort: sort));

    try {
      Stopwatch stopwatch = new Stopwatch()..start();
      var response = await _requester.get(API_PRODUCTS_BY_SEARCH_TERM.replaceAll("%", term),
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));
      var paginationResult = ProductPaginationResult.fromJson(response.data);
      print("Page ${paginationResult.page}/${paginationResult.maxPage} loaded in ${stopwatch.elapsedMilliseconds}ms");
      return ApiCallback(
          isSuccessful: true,
          resultData: paginationResult);
    } on DioError catch (e) {
      return ApiCallback.defaultErrorCallback(e);
//      return ApiCallback(
//          isSuccessful: false,
//          error: e,
//          resultErrorMessage:
//          ApiCallback.parseResponseError(e.response != null ? e.response.data : null));
    }
  }

  Future<ApiCallback<ProductPaginationResult>> getProductsByTag({String tag, int page = 1, int perPage = 20, String continuationToken, ProductOrder sort}) async {
    Map<String, dynamic> queryParameters = {
      'page': page,
      'perPage': perPage
    };

    queryParameters.addAll(_queryParametersForPagedProductRequest(continuationToken: continuationToken, sort: sort));

    try {
      Stopwatch stopwatch = new Stopwatch()..start();
      var response = await _requester.get(API_PRODUCTS_BY_TAG.replaceAll("%", tag),
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));
      var paginationResult = ProductPaginationResult.fromJson(response.data);
      print("Page ${paginationResult.page}/${paginationResult.maxPage} loaded in ${stopwatch.elapsedMilliseconds}ms");
      return ApiCallback(
          isSuccessful: true,
          resultData: paginationResult);
    } on DioError catch (e) {
      return ApiCallback.defaultErrorCallback(e);
    }
  }

  Map<String, dynamic> _queryParametersForPagedProductRequest({String continuationToken, ProductOrder sort}) {
    Map<String, dynamic> queryParameters = {};

    if (continuationToken != null) {
      queryParameters['continuationToken'] = continuationToken;
    }

    var sortParams = _queryParametersForProductSort(sort);
    queryParameters.addAll(sortParams);

    return queryParameters;
  }

  Map<String, dynamic> _queryParametersForProductSort(ProductOrder sort) {
    Map<String, dynamic> queryParameters = {};

    const SORT_FIELD_KEY = 'sortField';
    const SORT_ASCENDING_KEY = 'sortAscending';

    if (sort != null && sort.parameterName != null) {
      switch (sort) {
        case ProductOrder.none:
          break;
        case ProductOrder.lowestPrice:
          queryParameters[SORT_FIELD_KEY] = 'price';
          queryParameters[SORT_ASCENDING_KEY] = true;
          break;
        case ProductOrder.higherPrice:
          queryParameters[SORT_FIELD_KEY] = 'price';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.mostFavored:
          queryParameters[SORT_FIELD_KEY] = 'favoriteCount';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.bestSellers:
          queryParameters[SORT_FIELD_KEY] = 'salesCount';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.releaseDate:
          queryParameters[SORT_FIELD_KEY] = 'releaseDate';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.aToZ:
          queryParameters[SORT_FIELD_KEY] = 'name';
          queryParameters[SORT_ASCENDING_KEY] = true;
          break;
        case ProductOrder.zToA:
          queryParameters[SORT_FIELD_KEY] = 'name';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
      }
    }

    return queryParameters;
  }


  /// endregion

}

==> lori_sdk-0.3.3.tar.gz: lib/data/api/sales/sales_catalog_api.dart <==
import 'package:dio/dio.dart';
import 'package:flutter/material.dart';
import 'package:lori_sdk/data/lori_api.dart';
import 'package:lori_sdk/data/models/addressCep.dart';
import 'package:lori_sdk/data/models/product/product.dart';
import 'package:lori_sdk/data/models/product/productOrder.dart';
import 'package:lori_sdk/data/models/response/productPaginationResult.dart';
import 'package:lori_sdk/data/models/v2/category.dart';


class SalesCatalogApi {
  static const API_CATEGORIES = 'sales/catalog/categories';
  static const API_CATEGORIES_CHILDREN = 'sales/catalog/categories/%/children';

  static const API_PRODUCT_BY_ID = 'sales/catalog/products/%';
  static const API_PRODUCTS_BY_CATEGORY = 'sales/catalog/categories/%/products';
  static const API_PRODUCTS_BY_SEARCH_TERM = 'sales/catalog/products/search/%';
  static const API_PRODUCTS_BY_TAG = 'sales/catalog/tags/%/products';

  Dio _requester;

  SalesCatalogApi({@required Dio requester}) : this._requester = requester;

  /// region Category API endpoints

  Future<ApiCallback<List<Category>>> getCategories() async {
    try {
      var response = await _requester.get(API_CATEGORIES,
          options: Options(responseType: ResponseType.json));
      var responseData = response.data as List;
      var categories = List<Category>();
      for (var row in responseData) {
        categories.add(Category.fromJson(row));
      }
      categories.sort((c1, c2) => c1.name.compareTo(c2.name));
      return ApiCallback<List<Category>>(
          isSuccessful: true, resultData: categories);
    } on DioError catch (e) {
      return ApiCallback<List<Category>>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<List<Category>>> getChildrenCategories({String parentCategoryId}) async {
    try {
      var response = await _requester.get(API_CATEGORIES_CHILDREN.replaceAll('%', parentCategoryId),
        options: Options(responseType: ResponseType.json));
      var responseData = response.data as List;
      var categories = List<Category>();
      for (var row in responseData) {
        categories.add(Category.fromJson(row));
      }
      return ApiCallback<List<Category>>(
          isSuccessful: true, resultData: categories);
    } on DioError catch (e) {
      return ApiCallback<List<Category>>().defaultErrorCallback(e);
    }
  }

  /// endregion

  /// region Product API endpoints

  Future<ApiCallback<Product>> getProduct(String productId) async {
    try {
      var response = await _requester.get(API_PRODUCT_BY_ID.replaceAll('%', productId));
      return ApiCallback<Product>(
          isSuccessful: true, resultData: Product.fromJson(response.data));
    } on DioError catch (e) {
      return ApiCallback<Product>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<ProductPaginationResult>> getProductsByCategory({String categoryId, int page = 1, int perPage = 20, String continuationToken, ProductOrder sort}) async {
    Map<String, dynamic> queryParameters = {
      'page': page,
      'perPage': perPage
    };

    queryParameters.addAll(_queryParametersForPagedProductRequest(continuationToken: continuationToken, sort: sort));

    try {
      Stopwatch stopwatch = new Stopwatch()..start();
      var response = await _requester.get(API_PRODUCTS_BY_CATEGORY.replaceAll("%", categoryId),
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));
      var paginationResult = ProductPaginationResult.fromJson(response.data);
      print("Page ${paginationResult.page}/${paginationResult.maxPage} loaded in ${stopwatch.elapsedMilliseconds}ms");
      return ApiCallback<ProductPaginationResult>(
          isSuccessful: true,
          resultData: paginationResult);
    } on DioError catch (e) {
      return ApiCallback<ProductPaginationResult>().defaultErrorCallback(e);
    }
  }

  Future<ApiCallback<ProductPaginationResult>> getProductsBySearch({String term, int page = 1, int perPage = 20, String continuationToken, ProductOrder sort}) async {
    Map<String, dynamic> queryParameters = {
      'page': page,
      'perPage': perPage
    };

    queryParameters.addAll(_queryParametersForPagedProductRequest(continuationToken: continuationToken, sort: sort));

    try {
      Stopwatch stopwatch = new Stopwatch()..start();
      var response = await _requester.get(API_PRODUCTS_BY_SEARCH_TERM.replaceAll("%", term),
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));
      var paginationResult = ProductPaginationResult.fromJson(response.data);
      print("Page ${paginationResult.page}/${paginationResult.maxPage} loaded in ${stopwatch.elapsedMilliseconds}ms");
      return ApiCallback<ProductPaginationResult>(
          isSuccessful: true,
          resultData: paginationResult);
    } on DioError catch (e) {
      return ApiCallback<ProductPaginationResult>().defaultErrorCallback(e);
//      return ApiCallback(
//          isSuccessful: false,
//          error: e,
//          resultErrorMessage:
//          ApiCallback.parseResponseError(e.response != null ? e.response.data : null));
    }
  }

  Future<ApiCallback<ProductPaginationResult>> getProductsByTag({String tag, int page = 1, int perPage = 20, String continuationToken, ProductOrder sort}) async {
    Map<String, dynamic> queryParameters = {
      'page': page,
      'perPage': perPage
    };

    queryParameters.addAll(_queryParametersForPagedProductRequest(continuationToken: continuationToken, sort: sort));

    try {
      Stopwatch stopwatch = new Stopwatch()..start();
      var escapedTag = Uri.encodeComponent(tag);
      var response = await _requester.get(API_PRODUCTS_BY_TAG.replaceAll("%", escapedTag),
          queryParameters: queryParameters,
          options: Options(responseType: ResponseType.json));
      var paginationResult = ProductPaginationResult.fromJson(response.data);
      print("Page ${paginationResult.page}/${paginationResult.maxPage} loaded in ${stopwatch.elapsedMilliseconds}ms");
      return ApiCallback<ProductPaginationResult>(
          isSuccessful: true,
          resultData: paginationResult);
    } on DioError catch (e) {
      return ApiCallback<ProductPaginationResult>().defaultErrorCallback(e);
    }
  }

  Map<String, dynamic> _queryParametersForPagedProductRequest({String continuationToken, ProductOrder sort}) {
    Map<String, dynamic> queryParameters = {};

    if (continuationToken != null) {
      queryParameters['continuationToken'] = continuationToken;
    }

    var sortParams = _queryParametersForProductSort(sort);
    queryParameters.addAll(sortParams);

    return queryParameters;
  }

  Map<String, dynamic> _queryParametersForProductSort(ProductOrder sort) {
    Map<String, dynamic> queryParameters = {};

    const SORT_FIELD_KEY = 'sortField';
    const SORT_ASCENDING_KEY = 'sortAscending';

    if (sort != null && sort.parameterName != null) {
      switch (sort) {
        case ProductOrder.none:
          break;
        case ProductOrder.lowestPrice:
          queryParameters[SORT_FIELD_KEY] = 'price';
          queryParameters[SORT_ASCENDING_KEY] = true;
          break;
        case ProductOrder.higherPrice:
          queryParameters[SORT_FIELD_KEY] = 'price';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.mostFavored:
          queryParameters[SORT_FIELD_KEY] = 'favoriteCount';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.bestSellers:
          queryParameters[SORT_FIELD_KEY] = 'salesCount';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.releaseDate:
          queryParameters[SORT_FIELD_KEY] = 'releaseDate';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
        case ProductOrder.aToZ:
          queryParameters[SORT_FIELD_KEY] = 'name';
          queryParameters[SORT_ASCENDING_KEY] = true;
          break;
        case ProductOrder.zToA:
          queryParameters[SORT_FIELD_KEY] = 'name';
          queryParameters[SORT_ASCENDING_KEY] = false;
          break;
      }
    }

    return queryParameters;
  }


  /// endregion

}
